import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeCheckboxField from '@s-ui/react-molecule-checkbox-field';
import MoleculeField from '@s-ui/react-molecule-field';
import IconCheck from '../Icons/IconCheck';
import { createElement as _createElement } from "react";
import { jsx as _jsx } from "react/jsx-runtime";

var Multipicker = function Multipicker(_ref) {
  var multipicker = _ref.multipicker,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[multipicker.id];
  var alertMessages = alerts[multipicker.id];

  var onChangeCallback = function onChangeCallback(e) {
    var targetId = e.target.id;
    var checked = e.target.checked;
    var newValue = [];

    if (checked) {
      newValue = [].concat(multipicker.value, [targetId]);
    } else {
      newValue = multipicker.value.filter(function (id) {
        return id !== targetId;
      });
    }

    return onChange(multipicker.id, newValue);
  };

  var onFocusCallback = function onFocusCallback() {
    return onFocus(multipicker.id);
  };

  var onBlurCallback = function onBlurCallback() {
    return onBlur(multipicker.id);
  };

  var multipickerProps = _extends({
    id: multipicker.id,
    label: multipicker.label,
    value: multipicker.value,
    checkedIcon: IconCheck,
    onChange: onChangeCallback,
    onFocus: onFocusCallback,
    onBlur: onBlurCallback,
    tabIndex: tabIndex,
    intermediate: false
  }, multipicker.disabled && {
    disabled: true
  }, multipicker.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  if (multipickerProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: multipicker.id,
    innerProps: multipickerProps
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) {
    return rendererResponse;
  } // render SUI component


  return /*#__PURE__*/_jsx("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Multipicker sui-FormBuilder-" + (multipickerProps.id || tabIndex),
    children: /*#__PURE__*/_jsx(MoleculeField, _extends({}, multipickerProps, {
      children: multipicker.datalist.map(function (item) {
        var _multipicker$value;

        return /*#__PURE__*/_createElement(MoleculeCheckboxField, _extends({}, multipickerProps, rendererResponse, {
          key: item.value,
          label: item.text,
          id: item.value,
          checked: multipicker == null ? void 0 : (_multipicker$value = multipicker.value) == null ? void 0 : _multipicker$value.some(function (id) {
            return id === item.value;
          })
        }));
      })
    }))
  });
};

Multipicker.displayName = 'Multipicker';
export default /*#__PURE__*/memo(Multipicker, createComponentMemo('multipicker'));