import _extends from "@babel/runtime/helpers/esm/extends";
import { isValidElement, memo, useCallback } from 'react';
import PropTypes from 'prop-types';
import { field, createComponentMemo } from '../prop-types';
import MoleculeSwitch from '@s-ui/react-atom-switch';
import { jsx as _jsx } from "react/jsx-runtime";

var Switch = function Switch(_ref) {
  var switchField = _ref.switchField,
      tabIndex = _ref.tabIndex,
      onChange = _ref.onChange,
      errors = _ref.errors,
      alerts = _ref.alerts,
      renderer = _ref.renderer;
  var errorMessages = errors[switchField.id];
  var alertMessages = alerts[switchField.id];
  var switched = ['true', true].includes(switchField.value);
  var onChangeCallback = useCallback(function (value) {
    return onChange(switchField.id, JSON.stringify(value));
  }, [onChange, switchField]);

  var switchProps = _extends({
    name: switchField.id,
    label: switchField.label,
    initialValue: switched,
    value: switched,
    onToggle: onChangeCallback,
    type: 'single'
  }, switchField.disabled && {
    disabled: true
  }, switchField.hidden && {
    hidden: true
  }, !!errorMessages && {
    errorText: errorMessages.join('\n')
  }, !!alertMessages && {
    alertText: alertMessages.join('\n')
  });

  if (switchProps.hidden) {
    return null;
  }

  var rendererResponse = renderer({
    id: switchField.id,
    innerProps: switchProps
  }); // render custom component

  if ( /*#__PURE__*/isValidElement(rendererResponse)) return rendererResponse; // render SUI component

  return /*#__PURE__*/_jsx("div", {
    className: "sui-FormBuilder-field sui-FormBuilder-Switch sui-FormBuilder-" + (switchProps.id || tabIndex),
    children: /*#__PURE__*/_jsx(MoleculeSwitch, _extends({}, switchProps, rendererResponse))
  });
};

Switch.displayName = 'Switch';
export default /*#__PURE__*/memo(Switch, createComponentMemo('switchField'));